Crate utmt

Crate utmt 

Macros

assert_all
Multi-assertion macro. This macro take at least 1 argument as an expression. Several expressions can be added.
assert_match_option
Assert the Option<T> value. If the value is Some(...) return Ok(()), otherwise a Err value.
assert_match_result
Assert for a Result<T, E> value. If the value is a type of Ok(_) the result is Ok(()). If the value is a type of Err(_) the result is a type of Err(&str).
assert_not_match_option
Assert the Option<T> for a result that does not match the given argument. If the value is None return Ok(()) result. If the value is Some(...) return None result.
assert_not_match_result
Assert for a not validResult<T, E> value. If the value is a type of Err(_) the result is Ok(()). If the value is a type of Ok(_) the result is a type of Err(&str).
assert_slices_eq
Assertion about slices equality.
assert_slices_ne
Assertion about slices inequality.
fail
Force the test failure.
setup
Setup for unit test initialization.
teardown
Teardown for unit tests. The code of the teardown macro will be running automatically while the test will end, with test failure or not.